package com.muyu.task.server.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.muyu.common.core.domain.Result;
import com.muyu.common.domian.TaskInput;
import com.muyu.common.domian.req.*;
import com.muyu.common.domian.resp.NodeResp;
import com.muyu.task.server.service.NodeService;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
/**
 * @author Administrator
 */
@RestController
@RequestMapping("node")
public class NodeController {

    @Autowired
    private NodeService nodeService;
    /**
     * 获取所有的任务信息
     * @param req
     * @return
     */
    @PostMapping("list")
    @Operation(summary = "查看节点", description = "根据节点名称 权重 状态 查询")
    public Result list(@RequestBody TaskInputListReq req) {
        Page<TaskInput> list = nodeService.findList(req);
        return Result.success(list);
    }

    /**
     * 添加节点信息
     * @param req
     * @return
     */
    @PostMapping()
    @Operation(summary = "添加节点", description = "添加任务信息表")
    public Result save(@RequestBody @Validated TaskInputAddReq req) {
        nodeService.save(TaskInput.addBuild(req));
        return Result.success();
    }

    /**
     * 通过id查询任务信息
     * @param id
     * @return
     */
    @GetMapping("/{id}")
    @Operation(summary = "任务信息查询",description = "通过任务id查询任务信息")
    public Result<NodeResp> selectById(@PathVariable("id") Long id) {
        TaskInput byId = nodeService.getById(id);
        return Result.success(TaskInput.build(byId));
    }

    /**
     * 通过id删除任务
     * @param id
     * @return
     */
    @DeleteMapping("/{id}")
    @Operation(summary = "删除任务",description = "通过任务id删除任务信息")
    public Result delete(@PathVariable("id") Long id) {
        nodeService.removeById(id);
        return Result.success(null,"操作成功");
    }

    /**
     * 通过id修改任务
     * @param id
     * @param req
     * @return
     */

    @PutMapping("/{id}")
    @Operation(summary = "任务信息修改",description = "通过任务id修改任务信息")
    public Result update(@PathVariable("id") Integer id , @RequestBody TaskInputUpdReq req){
        nodeService.updateById(TaskInput.updBuild(req,()->id));
        return Result.success(null,"操作成功");
    }

}
